import * as React from 'react';
import { View, ScrollView, Platform, StyleSheet } from 'react-native';

import {
	Button,
	FabButton,
	TextInput,
	Chip,
	SectionSeparator,
	SegmentedView,
	IconButton,
} from 'react-native-elements-kit';

class App extends React.Component {
	constructor(props) {
		super(props);
		this.state = { fabButtonVisible: true, selectedChip: 'javascript', selectedSegmentId: '1' };
	}

	onButtonTouched = () => {
		this.setState({ fabButtonVisible: !this.state.fabButtonVisible });
	};
	onFabButtonTouched = () => {

	};
	onIconButtonTouched = () => {

	};
	onChipSelected = (chipKey) => {
		this.setState({ selectedChip: chipKey });
	};
	onSegmentSelected = (segmentId) => {
		this.setState({ selectedSegmentId: segmentId });
	};

	render() {
		const { fabButtonVisible, selectedChip, selectedSegmentId } = this.state;

		return (
			<View style={{ flex: 1 }}>
				<ScrollView style={styles.container}>
					<SectionSeparator title='Button Components' />

					<Button title='Button Component' onPress={this.onButtonTouched} />
					<Button title='Text Button Component' onPress={this.onButtonTouched} mode='text' />
					<IconButton iconComponent={(<View style={styles.iconButtonIcon} />)} />

					<SectionSeparator title='Text Input Component' />

					<TextInput placeholder='Enter Your Name' />
					<TextInput secureTextEntry placeholder='Password' />

					<SectionSeparator title='Chip Component' />

					<View style={styles.chipsContainer}>
						<Chip
							style={styles.chip}
							title='Javascript'
							selected={selectedChip === 'javascript'}
							onSelect={this.onChipSelected.bind(this, 'javascript')}
						/>
						<Chip
							style={styles.chip}
							title='Swift'
							selected={selectedChip === 'swift'}
							onSelect={this.onChipSelected.bind(this, 'swift')}
						/>
						<Chip
							style={styles.chip}
							title='Dart'
							selected={selectedChip === 'dart'}
							onSelect={this.onChipSelected.bind(this, 'dart')}
							disabled
						/>
					</View>

					<SectionSeparator title='Segmented View' />
					<SegmentedView
						selectedId={selectedSegmentId}
						onSelect={this.onSegmentSelected}
						segments={[
							{ id: '1', title: 'Male' },
							{ id: '2', title: 'Female' },
							{ id: '3', title: 'Another' },
						]}
					/>
				</ScrollView>
				<FabButton
					iconComponent={(<View style={styles.fabButtonIcon} />)}
					style={styles.fabButton}
					visible={fabButtonVisible}
					onPress={this.onFabButtonTouched}
				/>
			</View>
		);
	}
}

const styles = StyleSheet.create({
	container: {
		flex: 1,
		paddingTop: Platform.OS === 'ios' ? 50 : 0,
		paddingHorizontal: 36,

		backgroundColor: 'white',
	},
	fabButton: {
		position: 'absolute',
		end: 36,
		bottom: 36,
	},
	fabButtonIcon: {
		width: 24,
		height: 24,

		backgroundColor: 'white',
		borderRadius: 12,
	},
	iconButtonIcon: {
		width: 24,
		height: 24,

		backgroundColor: Platform.OS === 'ios' ? '#007AFF' : '#6002ee',
		borderRadius: 12,
	},
	chipsContainer: {
		flexDirection: 'row',
		marginVertical: 10,
	},
	chip: {
		marginEnd: 8,
	},
});

export default App;
