import * as React from 'react';
import { View, Text, TouchableOpacity, TouchableNativeFeedback, Platform } from 'react-native';
import PropTypes from 'prop-types';

import { getColorPalette } from './assets/colors';
import styles from './styles';

const Button = (props) => {
	const { title, onPress } = props;
	const colorPalette = getColorPalette(props.theme, props.accentColor, props.mode);

	const Touchable = Platform.OS === 'ios' ? TouchableOpacity : TouchableNativeFeedback;
	const touchableProps = Platform.select({
		ios: {},
		android: {
			background: new TouchableNativeFeedback.Ripple(colorPalette.ripple, false),
		},
	});

	return (
		<View style={[styles.container, props.style]}>
			<View style={styles.innerContainer}>
				<Touchable onPress={onPress} {...touchableProps}>
					<View style={styles.button(colorPalette.background)}>
						<Text style={[styles.title(colorPalette.text), props.titleStyle]}>{title}</Text>
					</View>
				</Touchable>
			</View>
		</View>
	);
};

Button.propTypes = {
	style: PropTypes.any,

	theme: PropTypes.oneOf(['light', 'dark']),
	accentColor: PropTypes.string,
	mode: PropTypes.oneOf(['normal', 'text']),

	title: PropTypes.string.isRequired,
	titleStyle: PropTypes.any,

	onPress: PropTypes.func.isRequired,
};

Button.defaultProps = {
	accentColor: require('../config').accent_color,
	mode: 'normal',
};

export default Button;
