/* @flow */

import * as React from 'react';
import { View, Text, TouchableOpacity } from 'react-native';
import PropTypes from 'prop-types';

import styles from './styles';

class Chip extends React.Component {
	onChipTouched = () => {
		const { onSelect, selected } = this.props;
		if (onSelect) onSelect(!selected);
	};

	render() {
		const { title, accentColor, selected, disabled } = this.props;

		return (
			<TouchableOpacity style={styles.touchable} onPress={this.onChipTouched} disabled={disabled}>
				<View style={[styles.container(accentColor, selected), this.props.style]}>
					<Text style={styles.text(accentColor, selected)}>{title}</Text>
				</View>
			</TouchableOpacity>
		);
	}
}

Chip.propTypes = {
	style: PropTypes.any,
	accentColor: PropTypes.string,

	title: PropTypes.string.isRequired,

	selected: PropTypes.bool,
	onSelect: PropTypes.func,
	disabled: PropTypes.bool,
};

Chip.defaultProps = {
	accentColor: require('../config').accent_color,

	selected: false,
	disabled: false,
};

export default Chip;
