import * as React from 'react';
import { View, Animated, Easing, Platform, TouchableOpacity, TouchableNativeFeedback } from 'react-native';
import PropTypes from 'prop-types';

import { getColorPalette } from './assets/colors';
import styles from './styles';

class FabButton extends React.Component {
	constructor(props) {
		super(props);
		this.animatedValue = new Animated.Value(props.visible ? 1 : 0);
	}

	componentWillReceiveProps(nextProps) {
		if (this.props.visible !== nextProps.visible) this.animateButton(nextProps.visible);
	}

	animateButton = (visible) => {
		Animated.timing(this.animatedValue, {
			toValue: visible ? 1 : 0,
			easing: Easing.linear,
			duration: 200,
		}).start();
	};

	render() {
		const { style, iconComponent, onPress } = this.props;
		const colorPalette = getColorPalette(this.props.theme, this.props.accentColor);

		const Touchable = Platform.OS === 'ios' ? TouchableOpacity : TouchableNativeFeedback;
		const touchableProps = Platform.select({
			ios: {},
			android: {
				background: new TouchableNativeFeedback.Ripple(colorPalette.ripple, false),
			},
		});

		const buttonSize = this.animatedValue.interpolate({ inputRange: [0, 1], outputRange: [0, 56] });
		const buttonMargin = this.animatedValue.interpolate({ inputRange: [0, 1], outputRange: [28, 0] });

		return (
			<Animated.View style={[styles.container(colorPalette.background, buttonSize, buttonMargin), style]}>
				<Touchable onPress={onPress} style={styles.touchable} {...touchableProps}>
					<View style={styles.touchableContent}>
						{iconComponent}
					</View>
				</Touchable>
			</Animated.View>
		);
	}
}

FabButton.propTypes = {
	style: PropTypes.any,

	theme: PropTypes.oneOf(['light', 'dark']),
	accentColor: PropTypes.string,

	iconComponent: PropTypes.element.isRequired,

	visible: PropTypes.bool,
	onPress: PropTypes.func.isRequired,
};

FabButton.defaultProps = {
	accentColor: require('../config').accent_color,
	visible: true,
};

export default FabButton;
