import * as React from 'react';
import { View, Platform, TouchableOpacity, TouchableNativeFeedback, StyleSheet } from 'react-native';
import PropTypes from 'prop-types';

import { getColorPalette } from './assets/colors';

const IconButton = (props) => {
	const { style, iconComponent, onPress } = props;
	const colorPalette = getColorPalette(props.theme, props.accentColor);

	const Touchable = Platform.OS === 'ios' ? TouchableOpacity : TouchableNativeFeedback;
	const touchableProps = Platform.select({
		ios: {},
		android: {
			background: new TouchableNativeFeedback.Ripple(colorPalette.ripple, false),
		},
	});

	return (
		<View style={[styles.container, style]}>
			<Touchable style={styles.touchable} onPress={onPress} {...touchableProps}>
				<View style={styles.touchableContent}>
					{iconComponent}
				</View>
			</Touchable>
		</View>
	);
};

const styles = StyleSheet.create({
	container: {
		width: 40,
		height: 40,

		borderRadius: 20,
		overflow: 'hidden',
	},
	touchable: {
		flex: 1,
		alignSelf: 'stretch',
	},
	touchableContent: {
		flex: 1,
		alignSelf: 'stretch',
		justifyContent: 'center',
		alignItems: 'center',
	},
});

IconButton.propTypes = {
	style: PropTypes.any,

	theme: PropTypes.oneOf(['light', 'dark']),
	accentColor: PropTypes.string,

	iconComponent: PropTypes.element.isRequired,
	onPress: PropTypes.func.isRequired,
};

IconButton.defaultProps = {
	theme: require('../config').theme,
	accentColor: require('../config').accent_color,
};

export default IconButton;
