import * as React from 'react';
import { View, Text, TouchableOpacity, Platform, TouchableNativeFeedback } from 'react-native';
import PropTypes from 'prop-types';

import styles from './styles';

const SegmentedView = (props) => {
	const handleSelection = (id: number) => {
		const { onSelect } = props;
		if (onSelect) onSelect(id);
	};

	const { style, segments, accentColor, selectedId } = props;

	const getSegment = (segment: { id: number, title: string }) => {
		const isSelected = selectedId === segment.id;

		const getTitle = () => {
			if (!segment.title) return undefined;
			return (
				<Text style={[styles.segmentTitle(isSelected, accentColor), props.textStyle]}>
					{segment.title}
				</Text>
			);
		};

		const Touchable = Platform.OS === 'ios' ? TouchableOpacity : TouchableNativeFeedback;

		return (
			<View key={segment.id} style={styles.segmentContainer}>
				<Touchable onPress={handleSelection.bind(this, segment.id)}>
					<View style={styles.segment(isSelected, accentColor)}>
						{getTitle()}
					</View>
				</Touchable>
			</View>
		);
	};

	const getSegments = () => {
		if (!segments) return undefined;
		return segments.map(getSegment);
	};

	return (
		<View style={[styles.container, style]}>
			{getSegments()}
		</View>
	);
};

SegmentedView.propTypes = {
	style: PropTypes.any,
	textStyle: PropTypes.any,
	accentColor: PropTypes.string,

	segments: PropTypes.arrayOf(PropTypes.object).isRequired,
	selectedId: PropTypes.any,

	onSelect: PropTypes.func,
};

SegmentedView.defaultProps = {
	accentColor: require('../config').accent_color,
};

export default SegmentedView;
